@@ -5,10 +5,10 @@
 import re
 import urllib.parse
 from dataclasses import dataclass
-from enum import Enum
-from typing import Optional
+from typing import Any, Optional
 
 from pontos.errors import PontosError
+from pontos.models import StrEnum
 
 __all__ = (
     "ANY",
@@ -28,7 +28,7 @@ class CPEParsingError(PontosError):
     """
 
 
-class Part(Enum):
+class Part(StrEnum):
     """
     Represents the possible values for a part CPE attribute
     """
@@ -79,7 +79,7 @@ def pack_extended_attributes(
     target_sw: Optional[str],
     target_hw: Optional[str],
     other: Optional[str],
-) -> Optional[str]:
+) -> str:
     """
     Pack the extended attributes (v2.3) for an edition attribute (v2.2)
     """
@@ -139,7 +139,7 @@ def _add_quoting(value: str) -> str:
     Add quoting for parsing attributes from formatted string format to
     Well-Formed CPE Name Data Model (WFN)
     """
-    result = ""
+    result: list[str] = []
     index = 0
     embedded = False
 
@@ -147,14 +147,14 @@ def _add_quoting(value: str) -> str:
         c = value[index]
         if c.isalnum() or c in ["_"]:
             # just add character
-            result += c
+            result.append(c)
             index += 1
             embedded = True
             continue
 
         if c == "\\":
             # keep escaped character
-            result += value[index : index + 2]
+            result.append(value[index : index + 2])
             index += 2
             embedded = True
             continue
@@ -163,7 +163,7 @@ def _add_quoting(value: str) -> str:
             # An unquoted asterisk must appear at the beginning or
             # end of the string.
             if index == 0 or index == (len(value) - 1):
-                result += c
+                result.append(c)
                 index += 1
                 embedded = True
                 continue
@@ -186,7 +186,7 @@ def _add_quoting(value: str) -> str:
                     embedded and (value[index + 1] == "?")
                 )
             ):
-                result += c
+                result.append(c)
                 index += 1
                 embedded = False
                 continue
@@ -197,11 +197,11 @@ def _add_quoting(value: str) -> str:
                 )
 
         # all other characters must be quoted
-        result += f"\\{c}"
+        result.append(f"\\{c}")
         index += 1
         embedded = True
 
-    return result
+    return "".join(result)
 
 
 def unbind_value_from_formatted_string(value: Optional[str]) -> Optional[str]:
@@ -726,3 +726,28 @@ class CPE:
             return self.as_uri_binding()
 
         return self.as_formatted_string_binding()
+
+    def __repr__(self) -> str:
+        return (
+            f"<{self.__class__.__name__} "
+            f'part="{self.part}" '
+            f'vendor="{self.vendor}" '
+            f'product="{self.product}" '
+            f'version="{self.version}" '
+            f'update="{self.update}" '
+            f'edition="{self.edition}" '
+            f'language="{self.language}" '
+            f'sw_edition="{self.sw_edition}" '
+            f'target_sw="{self.target_sw}" '
+            f'target_hw="{self.target_hw}" '
+            f'other="{self.other}"'
+            ">"
+        )
+
+    def __hash__(self) -> int:
+        return hash(str(self))
+
+    def __eq__(self, other: Any) -> bool:
+        if not isinstance(other, CPE):
+            return False
+        return str(self) == str(other)
