@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 Load and run Pontos GitHub Scripts
 
@@ -49,13 +37,13 @@ import httpx
 
 from pontos.errors import PontosError
 
+from ._parser import create_parser
 from .errors import GitHubScriptError
 from .load import (
     load_script,
     run_add_arguments_function,
     run_github_script_function,
 )
-from .parser import create_parser
 
 __all__ = (
     "GitHubScriptError",
@@ -78,6 +66,7 @@ def main():
             child_parser = ArgumentParser(parents=[parser])
             run_add_arguments_function(module, child_parser)
             args = child_parser.parse_args()
+
             token = args.token
             timeout = args.timeout
 
