@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import asyncio
 import importlib
@@ -61,8 +49,9 @@ def load_script(
     if path.suffix == ".py":
         module_name = path.stem
 
-        with add_sys_path(path.parent.absolute()), ensure_unload_module(
-            module_name
+        with (
+            add_sys_path(path.parent.absolute()),
+            ensure_unload_module(module_name),
         ):
             yield importlib.import_module(module_name)
     else:
