@@ -1,31 +1,20 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
 from datetime import datetime
 from types import TracebackType
 from typing import (
-    AsyncIterator,
-    Iterable,
+    Any,
+    Iterator,
     List,
     Optional,
     Type,
     Union,
 )
+from uuid import UUID
 
 from httpx import Timeout
 
@@ -34,6 +23,7 @@ from pontos.nvd.api import (
     DEFAULT_TIMEOUT_CONFIG,
     JSON,
     NVDApi,
+    NVDResults,
     Params,
     convert_camel_case,
     format_date,
@@ -45,6 +35,11 @@ DEFAULT_NIST_NVD_CPES_URL = "https://services.nvd.nist.gov/rest/json/cpes/2.0"
 MAX_CPES_PER_PAGE = 10000
 
 
+def _result_iterator(data: JSON) -> Iterator[CPE]:
+    results: list[dict[str, Any]] = data.get("products", [])  # type: ignore
+    return (CPE.from_dict(result["cpe"]) for result in results)
+
+
 class CPEApi(NVDApi):
     """
     API for querying the NIST NVD CPE information.
@@ -88,7 +83,7 @@ class CPEApi(NVDApi):
             rate_limit=rate_limit,
         )
 
-    async def cpe(self, cpe_name_id: str) -> CPE:
+    async def cpe(self, cpe_name_id: Union[str, UUID]) -> CPE:
         """
         Query for a CPE matching the CPE UUID.
 
@@ -114,7 +109,7 @@ class CPEApi(NVDApi):
         if not cpe_name_id:
             raise PontosError("Missing CPE Name ID.")
 
-        response = await self._get(params={"cpeNameId": cpe_name_id})
+        response = await self._get(params={"cpeNameId": str(cpe_name_id)})
         response.raise_for_status()
         data = response.json(object_hook=convert_camel_case)
         products = data["products"]
@@ -124,7 +119,7 @@ class CPEApi(NVDApi):
         product = products[0]
         return CPE.from_dict(product["cpe"])
 
-    async def cpes(
+    def cpes(
         self,
         *,
         last_modified_start_date: Optional[datetime] = None,
@@ -133,7 +128,9 @@ class CPEApi(NVDApi):
         keywords: Optional[Union[List[str], str]] = None,
         match_criteria_id: Optional[str] = None,
         request_results: Optional[int] = None,
-    ) -> AsyncIterator[CPE]:
+        start_index: int = 0,
+        results_per_page: Optional[int] = None,
+    ) -> NVDResults[CPE]:
         """
         Get all CPEs for the provided arguments
 
@@ -152,11 +149,15 @@ class CPEApi(NVDApi):
                 string identified by its UUID.
             request_results: Number of CPEs to download. Set to None (default)
                 to download all available CPEs.
+            start_index: Index of the first CPE to be returned. Useful only for
+                paginated requests that should not start at the first page.
+            results_per_page: Number of results in a single requests. Mostly
+                useful for paginated requests.
 
         Returns:
-            An async iterator of CPE model instances.
+            A NVDResponse for CPEs
 
-        Example:
+        Examples:
             .. code-block:: python
 
                 from pontos.nvd.cpe import CPEApi
@@ -164,6 +165,14 @@ class CPEApi(NVDApi):
                 async with CPEApi() as api:
                     async for cpe in api.cpes(keywords=["Mac OS X"]):
                         print(cpe.cpe_name, cpe.cpe_name_id)
+
+                    json = await api.cpes(request_results=10).json()
+
+                    async for cpes in api.cpes(
+                        cpe_match_string="cpe:2.3:o:microsoft:windows_7:-:*:*:*:*:*:*:*",
+                    ).chunks():
+                        for cpe in cpes:
+                            print(cpe)
         """
         params: Params = {}
         if last_modified_start_date:
@@ -187,52 +196,19 @@ class CPEApi(NVDApi):
         if match_criteria_id:
             params["matchCriteriaId"] = match_criteria_id
 
-        start_index = 0
-        downloaded_results = 0
-        results_per_page = (
-            request_results
-            if request_results and request_results < MAX_CPES_PER_PAGE
-            else MAX_CPES_PER_PAGE
+        results_per_page = min(
+            results_per_page or MAX_CPES_PER_PAGE,
+            request_results or MAX_CPES_PER_PAGE,
         )
-        total_results = None
-        requested_results = request_results
 
-        while (
-            requested_results is None or downloaded_results < requested_results
-        ):
-            params["startIndex"] = start_index
-
-            if results_per_page is not None:
-                params["resultsPerPage"] = results_per_page
-
-            response = await self._get(params=params)
-            response.raise_for_status()
-
-            data: JSON = response.json(object_hook=convert_camel_case)
-
-            results_per_page: int = data["results_per_page"]  # type: ignore
-            total_results: int = data["total_results"]  # type: ignore
-            products: Iterable = data.get("products", [])  # type: ignore
-
-            if not requested_results:
-                requested_results = total_results
-
-            for product in products:
-                yield CPE.from_dict(product["cpe"])
-
-            if results_per_page is None:
-                # just be safe here. should never occur
-                results_per_page = len(products)
-
-            start_index += results_per_page
-            downloaded_results += results_per_page
-
-            if (
-                request_results
-                and downloaded_results + results_per_page > request_results
-            ):
-                # avoid downloading more results then requested
-                results_per_page = request_results - downloaded_results
+        return NVDResults(
+            self,
+            params,
+            _result_iterator,
+            request_results=request_results,
+            results_per_page=results_per_page,
+            start_index=start_index,
+        )
 
     async def __aenter__(self) -> "CPEApi":
         await super().__aenter__()
