@@ -4,15 +4,15 @@
 
 from dataclasses import dataclass
 from datetime import datetime
-from enum import Enum
 from typing import Optional
 from uuid import UUID
 
-from pontos.models import Model
+from pontos.models import Model, StrEnum
 
 
-class EventName(str, Enum):
-    INITAL_ANALYSIS = "Initial Analysis"
+class EventName(StrEnum):
+    CVE_RECEIVED = "CVE Received"
+    INITIAL_ANALYSIS = "Initial Analysis"
     REANALYSIS = "Reanalysis"
     CVE_MODIFIED = "CVE Modified"
     MODIFIED_ANALYSIS = "Modified Analysis"
@@ -23,9 +23,8 @@ class EventName(str, Enum):
     CWE_REMAP = "CWE Remap"
     CVE_REJECTED = "CVE Rejected"
     CVE_UNREJECTED = "CVE Unrejected"
-
-    def __str__(self) -> str:
-        return self.value
+    CVE_CISA_KEV_UPDATE = "CVE CISA KEV Update"
+    REFERENCE_TAG_UPDATE = "Reference Tag Update"
 
 
 @dataclass
