@@ -1,28 +1,14 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 
 from typing import Iterator, Optional
 
-from pontos.git import Git, TagSort
-from pontos.git.git import DEFAULT_TAG_SORT_SUFFIX
+from pontos.git import DEFAULT_TAG_SORT_SUFFIX, Git, TagSort
 
-from .version import ParseVersionFuncType, Version
+from ._errors import VersionError
+from ._version import ParseVersionFuncType, Version
 
 
 def get_last_release_versions(
@@ -54,7 +40,12 @@ def get_last_release_versions(
     for tag in tag_list:
         last_release_version = tag.strip(git_tag_prefix)
 
-        version = parse_version(last_release_version)
+        try:
+            version = parse_version(last_release_version)
+        except VersionError:
+            # be safe and ignore invalid versions
+            continue
+
         if version.is_pre_release and ignore_pre_releases:
             continue
 
