@@ -1,19 +1,7 @@
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from unittest.mock import patch
@@ -119,6 +107,27 @@ class ActionIOTestCase(unittest.TestCase):
 
                 self.assertEqual(output, "foo=bar\nlorem=ipsum\n")
 
+    @patch("uuid.uuid1")
+    def test_multiline_output(self, uuid_mock):
+        deadbeef = "deadbeef"
+        name = "foo"
+        ml_string = """bar
+baz
+boing"""
+        expected_output = f"{name}<<{deadbeef}{ml_string}{deadbeef}"
+        uuid_mock.return_value = deadbeef
+        with temp_directory() as temp_dir:
+            file_path = temp_dir / "github.output"
+
+            with patch.dict(
+                "os.environ", {"GITHUB_OUTPUT": str(file_path)}, clear=True
+            ):
+                ActionIO.multiline_output("foo", ml_string)
+
+                output = file_path.read_text(encoding="utf8")
+
+                self.assertEqual(output, expected_output)
+
     @patch.dict("os.environ", {}, clear=True)
     def test_output_no_env(self):
         with self.assertRaises(GitHubActionsError):
