@@ -1,19 +1,7 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=redefined-builtin
 
@@ -58,6 +46,16 @@ class GitHubAsyncRESTLabelsTestCase(GitHubAsyncRESTTestCase):
             params={"per_page": "100"},
         )
 
+    async def test_delete_all(self):
+        response = create_response()
+        self.client.delete.return_value = response
+
+        await self.api.delete_all("foo/bar", 123)
+
+        self.client.delete.assert_awaited_once_with(
+            "/repos/foo/bar/issues/123/labels"
+        )
+
     async def test_set_all(self):
         response = create_response()
         self.client.post.return_value = response
