@@ -1,19 +1,6 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long
 
@@ -54,7 +41,7 @@ def get_cve_data(data: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
     return cve
 
 
-def get_cpe_data(update: Dict[str, Any] = None) -> Dict[str, Any]:
+def get_cpe_data(update: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
     data = {
         "deprecated": False,
         "cpe_name": "cpe:2.3:o:microsoft:windows_10_22h2:-:*:*:*:*:*:arm64:*",
@@ -66,3 +53,37 @@ def get_cpe_data(update: Dict[str, Any] = None) -> Dict[str, Any]:
     if update:
         data.update(update)
     return data
+
+
+def get_cve_change_data(
+    data: Optional[Dict[str, Any]] = None
+) -> Dict[str, Any]:
+    cve_changes = {
+        "cve_id": "CVE-2022-0001",
+        "event_name": "Initial Analysis",
+        "cve_change_id": "5160FDEB-0FF0-457B-AA36-0AEDCAB2522E",
+        "source_identifier": "nvd@nist.gov",
+        "created": "2022-03-18T20:13:08.123",
+        "details": [
+            {
+                "action": "Added",
+                "type": "CVSS V2",
+                "new_value": "NIST (AV:L/AC:L/Au:N/C:P/I:N/A:N)",
+            },
+            {
+                "action": "Added",
+                "type": "CVSS V3.1",
+                "new_value": "NIST AV:L/AC:L/PR:L/UI:N/S:C/C:H/I:N/A:N",
+            },
+            {
+                "action": "Changed",
+                "type": "Reference Type",
+                "old_value": "http://www.openwall.com/lists/oss-security/2022/03/18/2 No Types Assigned",
+                "new_value": "http://www.openwall.com/lists/oss-security/2022/03/18/2 Mailing List, Third Party Advisory",
+            },
+        ],
+    }
+
+    if data:
+        cve_changes.update(data)
+    return cve_changes
