@@ -1,26 +1,16 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long, arguments-differ, redefined-builtin
 # ruff: noqa: E501
 
-from datetime import datetime
-from typing import Any, Dict, List, Optional
+from datetime import datetime, timezone
+from itertools import repeat
+from typing import Any, Optional
 from unittest.mock import MagicMock, patch
+from uuid import UUID, uuid4
 
 from httpx import AsyncClient, Response
 
@@ -31,17 +21,37 @@ from tests import AsyncMock, IsolatedAsyncioTestCase, aiter, anext
 from tests.nvd import get_cpe_data
 
 
+def uuid_replace_str(uuid: UUID, iteration: int, number: int) -> str:
+    id_str = str(uuid).rsplit("-", 2)
+    nn = "".join([str(j) for j in repeat(number, 4)])
+    ii = "".join([str(j) for j in repeat(iteration, 12)])
+    return f"{id_str[0]}-{nn}-{ii}"
+
+
+def uuid_replace(uuid: UUID, iteration: int, number: int) -> UUID:
+    return UUID(uuid_replace_str(uuid, iteration, number))
+
+
 def create_cpe_response(
-    cpe_name_id: str,
+    cpe_name_id: UUID,
     *,
-    update: Optional[Dict[str, Any]] = None,
+    update: Optional[dict[str, Any]] = None,
     results: int = 1,
+    iteration: int = 1,
 ) -> MagicMock:
+    products = [
+        {
+            "cpe": get_cpe_data(
+                {
+                    "cpe_name_id": f"{uuid_replace_str(cpe_name_id, iteration, i)}"
+                }
+            )
+        }
+        for i in range(1, results + 1)
+    ]
+
     data = {
-        "products": [
-            {"cpe": get_cpe_data({"cpe_name_id": f"{cpe_name_id}-{i}"})}
-            for i in range(1, results + 1)
-        ],
+        "products": products,
         "results_per_page": results,
     }
     if update:
@@ -53,13 +63,14 @@ def create_cpe_response(
 
 
 def create_cpes_responses(
-    responses: int = 2, results_per_response: int = 1
-) -> List[MagicMock]:
+    cpe_name_id: UUID, responses: int = 2, results_per_response: int = 1
+) -> list[MagicMock]:
     return [
         create_cpe_response(
-            cpe_name_id=f"CPE-{i}",
+            cpe_name_id=cpe_name_id,
             update={"total_results": responses * results_per_response},
             results=results_per_response,
+            iteration=i,
         )
         for i in range(1, responses + 1)
     ]
@@ -91,26 +102,31 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             await self.api.cpe("CPE-1")
 
     async def test_cpe(self):
-        self.http_client.get.return_value = create_cpe_response("CPE-1")
+        uuid = uuid4()
+        self.http_client.get.return_value = create_cpe_response(uuid)
 
-        cpe = await self.api.cpe("CPE-1-1")
+        cpe = await self.api.cpe(uuid)
 
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
-            params={"cpeNameId": "CPE-1-1"},
+            params={"cpeNameId": str(uuid)},
         )
 
         self.assertEqual(
             cpe.cpe_name,
             "cpe:2.3:o:microsoft:windows_10_22h2:-:*:*:*:*:*:arm64:*",
         )
-        self.assertEqual(cpe.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cpe.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.assertFalse(cpe.deprecated)
         self.assertEqual(
-            cpe.last_modified, datetime(2022, 12, 9, 18, 15, 16, 973000)
+            cpe.last_modified,
+            datetime(2022, 12, 9, 18, 15, 16, 973000, tzinfo=timezone.utc),
+        )
+        self.assertEqual(
+            cpe.created,
+            datetime(2022, 12, 9, 16, 20, 6, 943000, tzinfo=timezone.utc),
         )
-        self.assertEqual(cpe.created, datetime(2022, 12, 9, 16, 20, 6, 943000))
 
         self.assertEqual(cpe.refs, [])
         self.assertEqual(cpe.titles, [])
@@ -123,7 +139,8 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         sleep_mock: MagicMock,
         monotonic_mock: MagicMock,
     ):
-        self.http_client.get.side_effect = create_cpes_responses(8)
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid, 8)
         monotonic_mock.side_effect = [10, 11]
 
         it = aiter(self.api.cpes())
@@ -141,15 +158,16 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
     @patch("pontos.nvd.cpe.api.now", spec=now)
     async def test_cves_last_modified_start_date(self, now_mock: MagicMock):
+        uuid = uuid4()
         now_mock.return_value = datetime(2022, 12, 31)
-        self.http_client.get.side_effect = create_cpes_responses()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(
             self.api.cpes(last_modified_start_date=datetime(2022, 12, 1))
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -165,7 +183,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -181,7 +199,8 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cves_last_modified_end_date(self):
-        self.http_client.get.side_effect = create_cpes_responses()
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(
             self.api.cpes(
@@ -191,7 +210,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -207,7 +226,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -223,12 +242,13 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cpes_keywords(self):
-        self.http_client.get.side_effect = create_cpes_responses()
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(self.api.cpes(keywords=["Mac OS X", "kernel"]))
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -244,7 +264,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -260,12 +280,13 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cpes_keyword(self):
-        self.http_client.get.side_effect = create_cpes_responses()
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(self.api.cpes(keywords="macOS"))
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -280,7 +301,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -295,7 +316,8 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cpes_cpe_match_string(self):
-        self.http_client.get.side_effect = create_cpes_responses()
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(
             self.api.cpes(
@@ -304,7 +326,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -319,7 +341,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -334,7 +356,8 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cpes_match_criteria_id(self):
-        self.http_client.get.side_effect = create_cpes_responses()
+        uuid = uuid4()
+        self.http_client.get.side_effect = create_cpes_responses(uuid)
 
         it = aiter(
             self.api.cpes(
@@ -343,7 +366,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
         )
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -358,7 +381,7 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
 
         cve = await anext(it)
 
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
         self.http_client.get.assert_awaited_once_with(
             "https://services.nvd.nist.gov/rest/json/cpes/2.0",
             headers={},
@@ -373,8 +396,9 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
             cve = await anext(it)
 
     async def test_cpes_request_results(self):
+        uuid = uuid4()
         self.http_client.get.side_effect = create_cpes_responses(
-            results_per_response=2
+            uuid, results_per_response=2
         )
 
         it = aiter(self.api.cpes(request_results=10))
@@ -388,11 +412,11 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
                 "resultsPerPage": 10,
             },
         )
-        self.assertEqual(cve.cpe_name_id, "CPE-1-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 1))
 
         self.http_client.get.reset_mock()
         cve = await anext(it)
-        self.assertEqual(cve.cpe_name_id, "CPE-1-2")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 1, 2))
         self.http_client.get.assert_not_called()
 
         self.http_client.get.reset_mock()
@@ -405,11 +429,11 @@ class CPEApiTestCase(IsolatedAsyncioTestCase):
                 "resultsPerPage": 2,
             },
         )
-        self.assertEqual(cve.cpe_name_id, "CPE-2-1")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 1))
 
         self.http_client.get.reset_mock()
         cve = await anext(it)
-        self.assertEqual(cve.cpe_name_id, "CPE-2-2")
+        self.assertEqual(cve.cpe_name_id, uuid_replace(uuid, 2, 2))
         self.http_client.get.assert_not_called()
 
         self.http_client.get.reset_mock()
