@@ -1,25 +1,13 @@
-# Copyright (C) 2022 Greenbone AG
+# SPDX-FileCopyrightText: 2022-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # pylint: disable=line-too-long
 # ruff: noqa: E501
 
 import unittest
-from datetime import date, datetime
+from datetime import date, datetime, timezone
 
 from pontos.nvd.models import cvss_v2, cvss_v3
 from pontos.nvd.models.cve import CVE, CVSSType, Operator
@@ -33,10 +21,12 @@ class CVETestCase(unittest.TestCase):
         self.assertEqual(cve.id, "CVE-2022-45536")
         self.assertEqual(cve.source_identifier, "cve@mitre.org")
         self.assertEqual(
-            cve.published, datetime(2022, 11, 22, 21, 15, 11, 103000)
+            cve.published,
+            datetime(2022, 11, 22, 21, 15, 11, 103000, tzinfo=timezone.utc),
         )
         self.assertEqual(
-            cve.last_modified, datetime(2022, 11, 23, 16, 2, 7, 367000)
+            cve.last_modified,
+            datetime(2022, 11, 23, 16, 2, 7, 367000, tzinfo=timezone.utc),
         )
         self.assertEqual(len(cve.descriptions), 1)
         self.assertEqual(len(cve.references), 2)
@@ -506,7 +496,9 @@ class CVETestCase(unittest.TestCase):
             comment.comment,
             "Fixed in Apache HTTP Server 1.3.12:\nhttp://httpd.apache.org/security/vulnerabilities_13.html",
         )
-        self.assertEqual(comment.last_modified, datetime(2008, 7, 2))
+        self.assertEqual(
+            comment.last_modified, datetime(2008, 7, 2, tzinfo=timezone.utc)
+        )
 
     def test_evaluator_comment(self):
         cve = CVE.from_dict(
