@@ -1,19 +1,7 @@
-# Copyright (C) 2021-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import contextlib
 import os
@@ -29,9 +17,10 @@ from pontos.release.helper import (
     find_signing_key,
     get_git_repository_name,
     get_next_release_version,
+    repository_split,
 )
 from pontos.testing import temp_git_repository
-from pontos.version.errors import VersionError
+from pontos.version import VersionError
 from pontos.version.schemes import SemanticVersioningScheme
 
 
@@ -305,3 +294,24 @@ class GetNextReleaseVersionTestCase(unittest.TestCase):
                 release_type=ReleaseType.ALPHA,
                 release_version=release_version,
             )
+
+
+class RepositorySplitTestCase(unittest.TestCase):
+    def test_invalid_repository(self):
+        with self.assertRaisesRegex(
+            ValueError,
+            r"Invalid repository foo/bar/baz. Format must be owner/name.",
+        ):
+            repository_split("foo/bar/baz")
+
+        with self.assertRaisesRegex(
+            ValueError,
+            r"Invalid repository foo_bar_baz. Format must be owner/name.",
+        ):
+            repository_split("foo_bar_baz")
+
+    def test_repository(self):
+        space, project = repository_split("foo/bar")
+
+        self.assertEqual(space, "foo")
+        self.assertEqual(project, "bar")
