@@ -1,25 +1,12 @@
-# Copyright (C) 2020-2022 Greenbone AG
+# SPDX-FileCopyrightText: 2020-2023 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import unittest
 from unittest.mock import patch
 
-from pontos.git.git import Git
-from pontos.version.errors import VersionError
+from pontos.git import Git
 from pontos.version.helper import (
     get_last_release_version,
     get_last_release_versions,
@@ -128,11 +115,18 @@ class GetLastReleaseVersionsTestCase(unittest.TestCase):
         ]
 
         it = get_last_release_versions(SemanticVersioningScheme.parse_version)
-        next(it)
 
-        with self.assertRaisesRegex(
-            VersionError, "3.55a1 is not valid SemVer string"
-        ):
+        version = next(it)
+        self.assertEqual(
+            version, SemanticVersioningScheme.parse_version("2.0.0")
+        )
+
+        version = next(it)
+        self.assertEqual(
+            version, SemanticVersioningScheme.parse_version("1.0.0")
+        )
+
+        with self.assertRaises(StopIteration):
             next(it)
 
 
@@ -204,12 +198,12 @@ class GetLastReleaseVersionTestCase(unittest.TestCase):
     @patch("pontos.version.helper.Git", spec=Git)
     def test_invalid_version(self, git_mock):
         git_interface = git_mock.return_value
-        git_interface.list_tags.return_value = ["1", "2", "3.55a1"]
+        git_interface.list_tags.return_value = ["1.0.0", "2.0.0", "3.55a1"]
 
-        with self.assertRaisesRegex(
-            VersionError, "3.55a1 is not valid SemVer string"
-        ):
-            get_last_release_version(SemanticVersioningScheme.parse_version)
+        self.assertEqual(
+            get_last_release_version(SemanticVersioningScheme.parse_version),
+            SemanticVersioningScheme.parse_version("2.0.0"),
+        )
 
     @patch("pontos.version.helper.Git", spec=Git)
     def test_success_with_invalid_version(self, git_mock):
